import React from 'react';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
export declare type DrawerRef = React.Ref<HTMLDivElement>;
export declare type DrawerProps = PropsWithMetadata<{
    /** Should be an instance of `DrawerHeader` followed by an instance of `DrawerBody` */
    children?: React.ReactNode;
    /** Allows providing a custom class name */
    className?: string;
    /**
     * Event keycode that should trigger the drawer to close.
     * Please, refer to [KeyboardEvent.key docs on MDN](https://developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key) for more details.
     */
    closeKey?: React.KeyboardEvent['key'];
    /** Controls the scrolling behavior of the document when the drawer is open */
    disabledBodyScrolling?: boolean;
    /** Controls the width of the drawer: `(100% - leftOffset)` */
    leftOffset?: string | number;
    /** Callback that is invoked after the drawer is closed */
    onClose?: any;
    /** Callback that is invoked after the drawer is opened */
    onOpen?: any;
    /** Callback that is invoked when the close key is pressed (if `preventToClose` is set to `false`) */
    onRequestToClose?: any;
    /** Controls whether the `onRequestToClose` callback should be executed or not */
    preventToClose?: boolean;
    /** Controls the height of the drawer: `(100% - topOffset)` */
    topOffset?: string | number;
    /** Controls the visibility of the drawer */
    visible?: boolean;
}>;
export default class Drawer extends React.PureComponent<DrawerProps> {
    ref: any | null | undefined;
    static defaultProps: {
        visible: boolean;
        disabledBodyScrolling: boolean;
        preventToClose: boolean;
        closeKey: string;
        topOffset: string;
        leftOffset: string;
        className: null;
        children: null;
        onOpen: () => void;
        onClose: () => void;
        onRequestToClose: () => void;
    };
    constructor(props: DrawerProps);
    componentDidMount(): void;
    componentDidUpdate(prevProps: DrawerProps): void;
    componentWillUnmount(): void;
    get sizeStyle(): Record<string, unknown>;
    determineBodyOverflowStyle: () => void;
    handleKeyDown: (event: KeyboardEvent) => void;
    render(): React.ReactNode;
}
